@@ -22,7 +22,12 @@ from ..grids.cartesian import CartesianGridBase
 from ..tools.cache import cached_method
 from ..tools.docstrings import fill_in_docstring
 from ..tools.numba import address_as_void_pointer, jit
-from ..tools.plotting import PlotReference, plot_on_axes
+from ..tools.plotting import (
+    PlotReference,
+    napari_add_layers,
+    napari_viewer,
+    plot_on_axes,
+)
 
 if TYPE_CHECKING:
     from .scalar import ScalarField  # @UnusedImport
@@ -472,6 +477,33 @@ class FieldBase(metaclass=ABCMeta):
     def plot(self, *args, **kwargs):
         pass
 
+    @abstractmethod
+    def _get_napari_data(self, **kwargs) -> Dict[str, Dict[str, Any]]:
+        pass
+
+    def plot_interactive(self, viewer_args: Dict[str, Any] = None, **kwargs):
+        """create an interactive plot of the field using :mod:`napari`
+
+        For a detailed description of the launched program, see the
+        `napari webpage <http://napari.org/>`_.
+
+        Args:
+            viewer_args (dict):
+                Arguments passed to :class:`napari.viewer.Viewer` to affect the viewer.
+            **kwargs:
+                Extra arguments passed to the plotting function
+        """
+        if viewer_args is None:
+            viewer_args = {}
+
+        if self.grid.num_axes == 1:
+            raise RuntimeError(
+                "Interactive plotting needs at least 2 spatial dimensions"
+            )
+
+        with napari_viewer(self.grid, **viewer_args) as viewer:
+            napari_add_layers(viewer, self._get_napari_data(**kwargs))
+
 
 TDataField = TypeVar("TDataField", bound="DataFieldBase")
 
@@ -1482,7 +1514,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
     def _plot_image(
         self,
         ax,
-        colorbar: bool = False,
+        colorbar: bool = True,
         scalar: str = "auto",
         transpose: bool = False,
         **kwargs,
@@ -1552,7 +1584,9 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         )
 
         # update the axes image
-        reference.element.set_array(data["data"])
+        reference.element.set_data(data["data"])
+        # adjust the colorbar limits
+        reference.element.set_clim(data["data"].min(), data["data"].max())
 
     def _plot_vector(
         self,
@@ -1663,7 +1697,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             raise ValueError(f"Unknown plot element {el.__class__.__name__}")
 
     @plot_on_axes(update_method="_update_plot")
-    def plot(self, kind: str = "auto", **kwargs):
+    def plot(self, kind: str = "auto", **kwargs) -> PlotReference:
         r"""visualize the field
 
         Args:
@@ -1717,19 +1751,37 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
         return reference
 
-    def plot_interactive(self, scalar: str = "auto", **kwargs):
-        """create an interactive plot of the field using :mod:`napari`
+    def _get_napari_layer_data(
+        self, scalar: str = "auto", args: Dict[str, Any] = None
+    ) -> Dict[str, Any]:
+        """returns data for plotting on a single napari layer
 
         Args:
-            scalar (str): The method for obtaining scalar values of fields
-            **kwargs: Extra arguments are passed to :class:`napari.Viewer`
-        """
-        from ..tools.plotting import napari_viewer
+            scalar (str):
+                Indicates how the scalar field is generated; see `to_scalar`
+            args (dict):
+                Additional arguments returned in the result, which affect how the layer
+                is shown.
 
-        with napari_viewer(self.grid, **kwargs) as viewer:
-            viewer.add_image(
-                self.to_scalar(scalar).data,
-                name=self.label,
-                rgb=False,
-                scale=self.grid.discretization,
-            )
+        Returns:
+            dict: all the information necessary to plot this field
+        """
+        result = {} if args is None else args.copy()
+
+        result.setdefault("scale", self.grid.discretization)
+        result.setdefault("rgb", False)
+        result["type"] = "image"
+        result["data"] = self.to_scalar(scalar).data
+        return result
+
+    def _get_napari_data(self, **kwargs) -> Dict[str, Dict[str, Any]]:
+        r"""returns data for plotting this field
+
+        Args:
+            \**kwargs: all arguments are forwarded to `_get_napari_layer_data`
+
+        Returns:
+            dict: all the information necessary to plot this field
+        """
+        name = "Field" if self.label is None else self.label
+        return {name: self._get_napari_layer_data(**kwargs)}
