@@ -6,7 +6,7 @@ grid.
 """
 
 import json
-from typing import Any, Dict, Iterator, List, Optional, Sequence, Union  # @UnusedImport
+from typing import Any, Dict, Iterator, List, Optional, Sequence, Union
 
 import numpy as np
 
@@ -41,7 +41,7 @@ class FieldCollection(FieldBase):
                 Label of the field collection
 
         Warning:
-            If `data` is given and `copy_fields == False`, the data in the
+            If `data` is given and :code:`copy_fields == False`, the data in the
             individual fields is overwritten by the associated `data`.
         """
         if isinstance(fields, FieldCollection):
@@ -164,6 +164,26 @@ class FieldCollection(FieldBase):
         """ list: the fields of this collection """
         return self._fields
 
+    @property
+    def labels(self) -> "_FieldLabels":
+        """:class:`_FieldLabels`: the labels of all fields
+
+        Note:
+            The attribute returns a special class :class:`_FieldLabels` to allow
+            specific manipulations of the field labels. The returned object behaves
+            much like a list, but assigning values will modify the labels of the fields
+            in the collection.
+        """
+        return _FieldLabels(self)
+
+    @labels.setter
+    def labels(self, values: List[Optional[str]]):
+        """ sets the labels of all fields """
+        if len(values) != len(self):
+            raise ValueError("Require a label for each field")
+        for field, value in zip(self.fields, values):
+            field.label = value
+
     def __eq__(self, other):
         """ test fields for equality, ignoring the label """
         if not isinstance(other, self.__class__):
@@ -521,7 +541,7 @@ class FieldCollection(FieldBase):
         # create a plot with all the panels
         if resize_fig:
             fig.set_size_inches((4 * len(self), 3), forward=True)
-        axs = fig.subplots(1, len(self))
+        (axs,) = fig.subplots(1, len(self), squeeze=False)
 
         # plot all the elements into the respective axes
         reference = [
@@ -532,20 +552,74 @@ class FieldCollection(FieldBase):
         # return the references for all subplots
         return reference
 
-    def plot_interactive(self, scalar: str = "auto", **kwargs):
-        """create an interactive plot of the field using :mod:`napari`
+    def _get_napari_data(self, **kwargs) -> Dict[str, Dict[str, Any]]:
+        r"""returns data for plotting all fields
 
         Args:
-            scalar (str): The method for obtaining scalar values of fields
-            **kwargs: Extra arguments are passed to :class:`napari.Viewer`
-        """
-        from ..tools.plotting import napari_viewer
+            \**kwargs: all arguments are forwarded to `_get_napari_layer_data`
 
-        with napari_viewer(self.grid, **kwargs) as viewer:
-            for field in self:
-                viewer.add_image(
-                    field.to_scalar(scalar).data,
-                    name=field.label,
-                    rgb=False,
-                    scale=self.grid.discretization,
-                )
+        Returns:
+            dict: all the information necessary to plot all fields
+        """
+        result = {}
+        for i, field in enumerate(self, 1):
+            name = f"Field {i}" if field.label is None else field.label
+            result[name] = field._get_napari_layer_data(**kwargs)
+        return result
+
+
+class _FieldLabels:
+    """ helper class that allows manipulating all labels of field collections"""
+
+    def __init__(self, collection: FieldCollection):
+        """
+        Args:
+            collection (:class:`pde.fields.collection.FieldCollection`):
+                The field collection that these labels are associated with
+        """
+        self.collection = collection
+
+    def __repr__(self):
+        return repr(list(self))
+
+    def __str__(self):
+        return str(list(self))
+
+    def __len__(self):
+        return len(self.collection)
+
+    def __eq__(self, other):
+        return list(self) == list(other)
+
+    def __iter__(self):
+        for field in self.collection:
+            yield field.label
+
+    def __getitem__(
+        self, index: Union[int, slice]
+    ) -> Union[Optional[str], List[Optional[str]]]:
+        """ return one or many labels of a field in the collection """
+        if isinstance(index, int):
+            return self.collection[index].label
+        elif isinstance(index, slice):
+            return list(self)[index]
+        else:
+            raise TypeError("Unsupported index type")
+
+    def __setitem__(
+        self, index: Union[int, slice], value: Union[Optional[str], List[Optional[str]]]
+    ):
+        """ change one or many labels of a field in the collection """
+        if isinstance(index, int):
+            assert isinstance(value, str)
+            self.collection.fields[index].label = value
+        elif isinstance(index, slice):
+            fields = self.collection.fields[index]
+            if value is None or isinstance(value, str):
+                value = [value] * len(fields)
+            if len(fields) != len(value):
+                raise ValueError("Require a label for each field")
+            for field, label in zip(fields, value):
+                field.label = label
+        else:
+            raise TypeError("Unsupported index type")
